agepy
=====

.. image:: https://img.shields.io/badge/version-0.2.3-blue
   :target: https://img.shields.io/badge/version-0.2.3-blue
.. image:: https://img.shields.io/badge/License-MIT-blue
   :target: https://github.com/exp4-age/agepy/blob/main/LICENSE
.. image:: https://github.com/exp4-age/agepy/actions/workflows/test.yml/badge.svg?branch=develop
   :target: https://github.com/exp4-age/agepy/tree/develop
.. image:: https://readthedocs.org/projects/exp4-agepy/badge/?version=latest
   :target: https://exp4-agepy.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://img.shields.io/pypi/v/exp4-agepy
   :target: https://pypi.org/project/exp4-agepy/
   :alt: PyPI - Version


Installation
------------

Install with ::

    pip install exp4-agepy

If you want to help develop and contribute to the package, first clone
the repository to your PC and install in editable mode (detailed 
tutorial in documentation)::

    pip install -e path/to/agepy


Documentation
-------------

The `documentation`_ is now on *Read the docs*.


Contributing
------------

See `CONTRIBUTING.rst <CONTRIBUTING.rst>`_


.. _documentation: https://exp4-agepy.readthedocs.io/en/latest/
